@@ -3,12 +3,9 @@ from imports import *
 from plotly_graphs import *
 from plotly_css import *
 
-external_stylesheets = ['https://raw.githubusercontent.com/rab657/explainx/master/explainx.css',
+external_stylesheets = ['https://raw.githubusercontent.com/rab657/explainx/master/explainx.css', dbc.themes.BOOTSTRAP,
 
-                            {
-                                'href': 'https://stackpath.bootstrapcdn.com/bootstrap/4.5.0/css/bootstrap.min.css',
-                                'rel': 'stylesheet'
-                            }, 
+                          
                             {
                                 'href':'https://fonts.googleapis.com/css?family=Montserrat',
                                 'rel' :'stylesheet'
